<p align="center" style="font-size:40px; margin:0px 10px 0px 10px">
    <em>ToyDL</em>
</p>
<p align="center">
    <em>Deep Learning from Scratch</em>
</p>

<p align="center">
<a href="https://codecov.io/gh/shenxiangzhuang/toydl" target="_blank">
    <img src="https://codecov.io/gh/shenxiangzhuang/toydl/branch/master/graph/badge.svg" alt="Coverage">
</a>
<a href="https://pypi.org/project/toydl" target="_blank">
    <img src="https://badge.fury.io/py/toydl.svg" alt="PyPI Package">
</a>
</p>

# Installation
```bash
pip install toydl
```
